@@ -544,8 +544,8 @@ bool QFSFileEngine::renameOverwrite(const QString &newName)
     bool ret = ::DeleteAndRenameFile((wchar_t*)QFileSystemEntry(newName).nativeFilePath().utf16(),
                                      (wchar_t*)d->fileEntry.nativeFilePath().utf16()) != 0;
     if (!ret) {
-        ret = ::DeleteFile((wchar_t*)d->fileEntry.nativeFilePath().utf16()) != 0;
-        if (ret)
+        ret = ::DeleteFile((wchar_t*)QFileSystemEntry(newName).nativeFilePath().utf16()) != 0;
+        if (ret || ::GetLastError() == ERROR_FILE_NOT_FOUND)
             ret = ::MoveFile((wchar_t*)d->fileEntry.nativeFilePath().utf16(),
                              (wchar_t*)QFileSystemEntry(newName).nativeFilePath().utf16()) != 0;
     }
